@@ -229,7 +229,7 @@ class SectionImport(Section):
         self.multi = None
         if is_include:
             self.module = module
-        elif module is not None and module is not '':
+        elif module is not None and module != '':
             self.module = 'modules/' + module
         else:
             if not 'testie' in params:
@@ -380,6 +380,8 @@ class SectionVariable(Section):
         if not var in self.vlist:
             print("WARNING : %s does not override anything" % var)
         if isinstance(val, Variable):
+            if val.is_default:
+                return
             if val.assign == '+=':
                 self.vlist[var] += val
             elif val.assign == '?=' and not var in self.vlist:
@@ -495,13 +497,19 @@ class SectionLateVariable(SectionVariable):
 
 class SectionConfig(SectionVariable):
     def __add(self, var, val):
-        self.vlist[var.lower()] = SimpleVariable(var, val)
+        v = SimpleVariable(var, val)
+        v.is_default = True
+        self.vlist[var.lower()] = v
 
     def __add_list(self, var, list):
-        self.vlist[var.lower()] = ListVariable(var, list)
+        v = ListVariable(var, list)
+        v.is_default = True
+        self.vlist[var.lower()] = v
 
     def __add_dict(self, var, dict):
-        self.vlist[var.lower()] = DictVariable(var, dict)
+        v = DictVariable(var, dict)
+        v.is_default = True
+        self.vlist[var.lower()] = v
 
     def __init__(self):
         super().__init__('config')
@@ -550,6 +558,7 @@ class SectionConfig(SectionVariable):
         self.__add("critical", False)
         self.__add_dict("env", {})  # Unimplemented yet
         self.__add("timeout", 30)
+        self.__add("hardkill", 5000)
         self.__add("time_precision", 1)
         self.__add("time_sync", True)
         self.__add_list("glob_sync", [])
@@ -573,6 +582,8 @@ class SectionConfig(SectionVariable):
         self.__add_dict('graph_x_sort', {})
         self.__add("graph_scatter", False)
         self.__add("graph_show_values", False)
+
+        self.__add("graph_show_xlabel", True)
         self.__add("graph_subplot_type", "subplot")
         self.__add("graph_max_series", None)
         self.__add("graph_series_as_variables", False)
@@ -622,6 +633,9 @@ class SectionConfig(SectionVariable):
         self.__add_list("graph_type", [])
         self.__add("title", None)
         self.__add_list("require_tags", [])
+        self.__add_dict("var_label_dir", {})
+        self.__add("graph_force_diagonal_labels", False)
+        self.__add("graph_smooth", 1)
 
     def var_name(self, key):
         key = key.lower()
