@@ -106,16 +106,19 @@ class Testie:
         return self.scripts
 
     def __init__(self, testie_path, options, tags=None, role=None):
-        if os.path.exists(npf.find_local(testie_path)):
-            testie_path = npf.find_local(testie_path)
+        loc_path = npf.find_local(testie_path)
+        if os.path.exists(loc_path):
+            testie_path = loc_path
         else:
-            testie_path = npf.find_local(testie_path + '.npf')
-            if not os.path.exists(testie_path):
+            loc_path = npf.find_local(testie_path + '.npf')
+            if not os.path.exists(loc_path):
                 if os.path.exists(npf.find_local(testie_path + '.testie')):
                     printf("WARNING: .testie extension is deprecated, use .npf")
                     testie_path = npf.find_local(testie_path + '.testie')
                 else:
-                    raise Exception("Could not find test script %s" % testie_path)
+                    raise FileNotFoundError("Could not find test script %s (tried also with .npf and .testie extensions, without success)" % testie_path)
+            else:
+                testie_path = loc_path
 
         self.sections = []
         self.files = []
@@ -224,6 +227,12 @@ class Testie:
             for k, v in imp.params.items():
                 overriden_variables[k] = VariableFactory.build(k, v)
             imp.testie.variables.override_all(overriden_variables)
+
+            if "require_tags" in imp.testie.config.vlist:
+                imp.testie.config.vlist["require_tags"] = imp.testie.config.vlist["require_tags"].pop("import")
+
+            imp.testie.config.override_all(self.config.vlist)
+            self.config = imp.testie.config
             if not imp.is_include:
                 for script in imp.testie.scripts:
                     if script.get_role():
@@ -392,8 +401,7 @@ class Testie:
                 pass
 
     def update_constants(self, v_internals, build, full_test_folder, out_path):
-        print(full_test_folder)
-        v_internals.update({ 'NPF_REPO':get_valid_filename(build.repo.name),'NPF_ROOT': '../', 'NPF_BUILD': '../' + build.build_path(),
+        v_internals.update({ 'NPF_REPO':get_valid_filename(build.repo.name),'NPF_ROOT': '../', 'NPF_BUILD': ('../' + build.build_path()) if not os.path.isabs(build.build_path()) else build.build_path(),
                         'NPF_TESTIE_PATH':os.path.relpath(self.path if self.path else "./",full_test_folder),
                         'NPF_RESULT_PATH':os.path.relpath(build.result_folder(), full_test_folder)})
         if out_path:
@@ -858,7 +866,8 @@ class Testie:
                 if has_values:
                     break
 
-                for result_type in self.config.get_list('results_expect'):
+                if script.type == SectionScript.TYPE_SCRIPT:
+                  for result_type in self.config.get_list('results_expect'):
                     if result_type not in data_results and not result_type in all_kind_results:
                         print("Could not find expected result '%s' !" % result_type)
                         has_err = True
@@ -944,7 +953,7 @@ class Testie:
                 raise ScriptInitException()
 
     def execute_all(self, build, options, prev_results: Dataset = None, do_test=True, on_finish=None,
-                    allowed_types=SectionScript.ALL_TYPES_SET, prev_kind_results: Dict[str, Dataset] = None) -> Tuple[
+                    allowed_types=SectionScript.ALL_TYPES_SET, prev_kind_results: Dict[str, Dataset] = None, iserie=0,nseries=1) -> Tuple[
         Dataset, bool]:
         """Execute script for all variables combinations. All tools reliy on this function for execution of the testie
         :param allowed_types:Tyeps of scripts allowed to run. Set with either init, scripts or both
@@ -1132,7 +1141,7 @@ class Testie:
                             def print_header(i, i_try):
                                 n_try=int(self.config["n_retry"])
                                 print(run.format_variables(self.config["var_hide"]),
-                                  "[%srun %d/%d for test %d/%d]" % (  ("retrying %d/%d " % (i_try + 1,n_try)) if i_try > 0 else "", i+1, n_runs, n, len(self.variables)))
+                                  ("[%srun %d/%d for test %d/%d"+(" of serie %d/%d" %(iserie+1,nseries) if nseries > 1 else "")+"]") % (  ("retrying %d/%d " % (i_try + 1,n_try)) if i_try > 0 else "", i+1, n_runs, n, len(self.variables)))
                         else:
                             print("Executing single run...")
 
@@ -1287,7 +1296,7 @@ class Testie:
             s = excludes.split('+')
             m = set()
             for role in s:
-                nodes = npf.node_for_roles(role)
+                nodes = npf.nodes_for_role(role)
                 for node in nodes:
                   if node in m:
                     return False
